<?php
/**
 * Industrial App - Message Metabox 
 *
 * @package industrial-app
 * @subpackage industrial-app.metabox
 * @since industrial-app 1.0.0 
 */
$prefix = 'industrialcore_';
global $industrial_message_option_meta;
$industrial_message_option_meta = array(
    'id' => 'message-meta',
    'title' => __('Award message section setting', 'industrial'),
    'page' => 'message',
    'context' => 'normal',
    'priority' => 'high',
    'fields' => array(
        array(
            'name' => __('Message', 'industrial'),
            'desc' => '',
            'id' => $prefix . 'full_message',
            "type" => "textarea",
            'std' => ''
        ),
        array(
            'name' => __('First photo', 'industrial'),
            'desc' => __('Upload a photo', 'industrial'),
            'id' => $prefix . 'f_message_image',
            "type" => "text",
            'std' => ''
        ),
        array(
            'name' => '',
            'desc' => '',
            'id' => $prefix . 'f_message_image_button',
            'type' => 'button',
            'std' => 'Browse'
        ),
        array(
            'name' => __('Second photo', 'industrial'),
            'desc' => __('Upload a photo', 'industrial'),
            'id' => $prefix . 's_message_image',
            "type" => "text",
            'std' => ''
        ),
        array(
            'name' => '',
            'desc' => '',
            'id' => $prefix . 's_message_image_button',
            'type' => 'button',
            'std' => ''
        )
    )
);
// create boxes for team
add_action('admin_menu', 'industrial_add_message_meta_boxes');

function industrial_add_message_meta_boxes() {
    global $industrial_message_option_meta;
    add_meta_box($industrial_message_option_meta['id'], $industrial_message_option_meta['title'], 'industrial_show_message_options', $industrial_message_option_meta['page'], $industrial_message_option_meta['context'], $industrial_message_option_meta['priority']);
}

function industrial_show_message_options() {
    global $industrial_message_option_meta, $post;
    // Use nonce for verification]
    wp_nonce_field(basename(__FILE__), 'meta_box_nonce');
    ?>
    <table class="form-table"><?php
        foreach ($industrial_message_option_meta['fields'] as $field) {
            // get current post meta data
            $meta = get_post_meta($post->ID, $field['id'], true);


            switch ($field['type']) {
                case 'text':
                    $src = wp_get_attachment_image_src($meta, 'full');
                    $meta = $src[0];
                    ?>
                    <tr>
                        <th style="width:25%">
                            <label for="<?php echo $field['id']; ?>">
                                <strong><?php echo $field['name']; ?></strong>
                                <span style=" display:block; color:#999; margin:5px 0 0 0; line-height: 18px;"><?php echo $field['desc']; ?></span>
                            </label>
                        </th>
                        <td>
                            <input type="text" name="<?php echo $field['id']; ?>" id="<?php echo $field['id']; ?>" value="<?php echo $meta ? $meta : stripslashes(htmlspecialchars(($field['std']), ENT_QUOTES)); ?>" size="30" style="width:75%; margin-right: 20px; float:left;" />
                            <!--/td>
                        </tr-->
                            <?php
                            break;
                        case 'button':
                            $src = wp_get_attachment_image_src($meta, 'full');
                            $meta = $src[0];
                            ?><input style="float: left;" type="button" class="industrialcore_upload_image_button" name="<?php echo $field['id']; ?>" id="<?php echo $field['id']; ?>" value="Browse" />
                            <img width="100%" height="150px" src="<?php echo $meta ? $meta : stripslashes(htmlspecialchars(($field['std']), ENT_QUOTES)); ?>" />
                        </td>
                    </tr>
                    <?php
                    break;
                case 'textarea':
                    ?><tr>
                        <th style="width:25%">
                            <label for="<?php echo $field['id']; ?>">
                                <strong><?php echo $field['name']; ?></strong>
                                <span style=" display:block; color:#999; margin:5px 0 0 0; line-height: 18px;"><?php echo $field['desc']; ?></span>
                            </label>
                        </th>
                        <td>
                            <?php
                            $args = array(
                                'textarea_rows' => 5,
                                'media_buttons' => false,
                                'wpautop' => false,
                                'teeny' => true,
                                'quicktags' => false
                            );
                            wp_editor($meta ? $meta : stripslashes(htmlspecialchars(($field['std']), ENT_QUOTES)), $field['id'], $args);
                            ?></td></tr><?php
                    break;
            } //endswitch
        }//endforech
        ?></table>
    <script>
        (function ($) {
            $(document).on("click", ".industrialcore_upload_image_button", function () {
                var adMediaFrame = wp.media({
                    title: 'Industrial - Insert a media',
                    library: {type: 'image'},
                    multiple: false,
                    button: {text: 'Insert'}
                });
                adMediaFrame.open();

                var inputText = $(this).prev();
                var inputImg = $(this).next();
                var imageURL, attachment;
                adMediaFrame.on('select', function () {
                    attachment = adMediaFrame.state().get('selection').first().toJSON();
                    imageURL = attachment.url;
                    if (imageURL != "") {
                        inputText.val(imageURL);
                        inputImg.attr("src", imageURL);
                    }
                });
                return false;
            });
        })(jQuery);

    </script>

    <?php
}

add_action('save_post', 'industrial_message_save_options');

// save team metadata
function industrial_message_save_options($post_id) {
    global $industrial_message_option_meta;
    $new = '';
    if (!isset($_POST['meta_box_nonce']) || !wp_verify_nonce($_POST['meta_box_nonce'], basename(__FILE__))) {
        return $post_id;
    }
    // check autosave
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return $post_id;
    }
    if (defined('DOING_AJAX') && DOING_AJAX)
        return;
    // check permissions
    if (isset($_POST['post_type']) && 'page' == $_POST['post_type']) {
        if (!current_user_can('edit_page', $post_id)) {
            return $post_id;
        }
    } elseif (!current_user_can('edit_post', $post_id)) {
        return $post_id;
    }


    foreach ($industrial_message_option_meta['fields'] as $field) {
        $old = get_post_meta($post_id, $field['id'], true);
        if (isset($_POST[$field['id']])) {
            $new = $_POST[$field['id']];
        }
        if ($new && $new != $old) {
            if ($field['id'] == 'industrialcore_f_message_image' || $field['id'] == 'industrialcore_s_message_image') {

                $new = industrialcore_get_image_id($new);
            }
            update_post_meta($post_id, $field['id'], $new);
        } elseif ('' == $new && $old) {
            delete_post_meta($post_id, $field['id'], $old);
        }
    }
}
