<?php
/**
 * Industrial App - Page Metabox 
 *
 * @package industrial-app
 * @subpackage industrial-app.metabox
 * @since industrial-app 1.0.0 
 */
global $industrial_page_metabox_args;

$prefix = 'industrialcore_';
$industrial_page_metabox_args = array(
    'id' => 'section-page-meta',
    'title' => __('Page Meta Setting', 'CustomPostType'),
    'page' => 'page',
    'context' => 'normal',
    'priority' => 'high',
    'fields' => array(
        array(
            'name' => __('Slider Shortcode', 'CustomPostType'),
            'desc' => '',
            'id' => $prefix . 'slider_slider',
            'type' => 'text',
            'std' => ''
        ),
    )
);

// create boxes for team
add_action('admin_menu', 'industrial_page_add_metabox_settings');

function industrial_page_add_metabox_settings() {
    global $industrial_page_metabox_args;
    add_meta_box($industrial_page_metabox_args['id'], $industrial_page_metabox_args['title'], 'industrial_page_metabox_settings_ui', $industrial_page_metabox_args['page'], $industrial_page_metabox_args['context'], $industrial_page_metabox_args['priority']);
}

function industrial_page_metabox_settings_ui() {
    global $industrial_page_metabox_args, $post;
    // Use nonce for verification
    wp_nonce_field(basename(__FILE__), 'meta_box_nonce');
    ?>
    <table class="form-table">
        <?php
        foreach ($industrial_page_metabox_args['fields'] as $field) {
            // get current post meta data
            $meta = get_post_meta($post->ID, $field['id'], true);
            switch ($field['type']) {
                case 'text':
                    ?><tr>
                        <th style="width:25%"><label for="<?php echo $field['id']; ?>">
                                <strong><?php echo $field['name']; ?></strong>
                                <span style=" display:block; color:#999; margin:5px 0 0 0; line-height: 18px;"><?php echo $field['desc']; ?></span>
                            </label>
                        </th>
                        <td>
                            <input type="text" name="<?php echo $field['id']; ?>" id="<?php echo $field['id']; ?>" value="<?php echo $meta ? stripslashes(htmlspecialchars(($meta), ENT_QUOTES)) : stripslashes(htmlspecialchars(($field['std']), ENT_QUOTES)); ?>" size="30" style="width:75%; margin-right: 20px; float:left;" />
                        </td></tr> 
                    <?php
                    break;
            } //endswitch
        } //endforeach
        ?></table><?php
}

add_action('save_post', 'industrial_page_save_metabox_settings');

function industrial_page_save_metabox_settings($post_id) {
    global $industrial_page_metabox_args;
    $new = '';
// verify nonce
    if (!isset($_POST['meta_box_nonce']) || !wp_verify_nonce($_POST['meta_box_nonce'], basename(__FILE__))) {
        return $post_id;
    }
// check autosave
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return $post_id;
    }
    if (defined('DOING_AJAX') && DOING_AJAX)
        return;
// check permissions
    if (isset($_POST['post_type']) && 'page' == $_POST['post_type']) {
        if (!current_user_can('edit_page', $post_id)) {
            return $post_id;
        }
    } elseif (!current_user_can('edit_post', $post_id)) {
        return $post_id;
    }

    foreach ($industrial_page_metabox_args['fields'] as $field) {
        $old = get_post_meta($post_id, $field['id'], true);
        if (isset($_POST[$field['id']])) {
            $new = $_POST[$field['id']];
        }
        if ($new && $new != $old) {
            update_post_meta($post_id, $field['id'], $new);
        } elseif ('' == $new && $old) {
            delete_post_meta($post_id, $field['id'], $old);
        }
    }
}
