<?php
/**
 * Industrial App - Team Metabox 
 *
 * @package industrial-app
 * @subpackage industrial-app.metabox
 * @since industrial-app 1.0.0 
 */
$prefix = 'industrialcore_';

$industrial_team_option_meta = array(
    'id' => 'team-meta',
    'title' => __('Team home section setting', 'industrial'),
    'page' => 'team',
    'context' => 'normal',
    'priority' => 'high',
    'fields' => array(
        array(
            'name' => __('Member Position', 'industrial'),
            'desc' => '',
            'id' => $prefix . 'team_position',
            "type" => "text",
            'std' => ''
        ),
        array(
            'name' => __('Description', 'industrial'),
            'desc' => '',
            'id' => $prefix . 'team_decription',
            "type" => "textarea",
            'std' => ''
        ),
        array(
            'name' => __('Member photo', 'industrial'),
            'desc' => __('Upload a member photo image', 'industrial'),
            'id' => $prefix . 'team_image',
            "type" => "text",
            'std' => ''
        ),
        array(
            'name' => '',
            'desc' => '',
            'id' => $prefix . 'team_image_button',
            'type' => 'button',
            'std' => 'Browse'
        ),
        array(
            'name' => __('Facebook link', 'industrial'),
            'desc' => __('Enter Facebook link', 'industrial'),
            'id' => $prefix . 'team_Facebook',
            "type" => "text",
            'std' => ''
        ),
        array(
            'id' => $prefix . 'team_Facebook_show',
            "type" => "social",
            'val' => 'facebook'
        ),
        array(
            'name' => __('Twitter link', 'industrial'),
            'desc' => __('Enter Twitter link', 'industrial'),
            'id' => $prefix . 'team_Twitter',
            "type" => "text",
            'std' => ''
        ),
        array(
            'id' => $prefix . 'team_Twitter_show',
            "type" => "social",
            'val' => 'twitter'
        ),
        array(
            'name' => __('GoolePlus link', 'industrial'),
            'desc' => __('Enter GoolePlus link', 'industrial'),
            'id' => $prefix . 'team_googleplus',
            "type" => "text",
            'std' => ''
        ),
        array(
            'id' => $prefix . 'team_googleplus_show',
            "type" => "social",
            'val' => 'googleplus'
        ),
        array(
            'name' => '',
            'desc' => '',
            'id' => $prefix . 'team_clear_fields',
            'type' => 'button-clear',
            'std' => 'Clear Meta'
        )
    )
);
// create boxes for team
add_action('admin_menu', 'industrial_add_team_meta_boxes');

function industrial_add_team_meta_boxes() {
    global $industrial_team_option_meta;
    add_meta_box($industrial_team_option_meta['id'], $industrial_team_option_meta['title'], 'industrial_show_team_options', $industrial_team_option_meta['page'], $industrial_team_option_meta['context'], $industrial_team_option_meta['priority']);
}

function industrial_show_team_options() {
    global $industrial_team_option_meta, $post;
    // Use nonce for verification
    wp_nonce_field(basename(__FILE__), 'meta_box_nonce');
    ?>
    <table class="form-table">
        <?php
        foreach ($industrial_team_option_meta['fields'] as $field) {
            // get current post meta data
            $meta = get_post_meta($post->ID, $field['id'], true);
            switch ($field['type']) {
                case 'text':
                    if ($field['id'] == 'industrialcore_team_image') {
                        $src = wp_get_attachment_image_src($meta, 'full');
                        $meta = $src[0];
                    }
                    ?><tr>
                        <th style="width:25%">
                            <label for="<?php echo $field['id']; ?>">
                                <strong><?php echo $field['name']; ?></strong>
                                <span style=" display:block; color:#999; margin:5px 0 0 0; line-height: 18px;"><?php echo $field['desc']; ?></span>
                            </label></th>
                        <td>
                            <input type="text" name="<?php echo $field['id']; ?>" id="<?php echo $field['id']; ?>" value="<?php echo $meta ? $meta : stripslashes(htmlspecialchars(($field['std']), ENT_QUOTES)); ?>" size="30" style="width:75%; margin-right: 20px; float:left;" />
                            <?php
                            break;
                        case 'social':
                            ?><input type="checkbox" name="<?php echo $field['id']; ?>" id="<?php echo $field['id']; ?>" value="<?php echo $field['val']; ?>" <?php echo (isset($meta) && $meta == $field['val']) ? 'checked' : ''; ?>/>
                            <?php
                            break;
                        case 'button':
                            ?><input style="float: left;" type="button" class="industrialcore_upload_image_button" name="<?php echo $field['id']; ?>" id="<?php echo $field['id']; ?>" value="Browse" />
                        </td>
                    </tr><?php
                    break;
                case 'button-clear':
                    ?><tr>
                        <td colspan="2">
                            <input style="float: right;" type="button" class="button" name="<?php echo $field['id']; ?>" id="<?php echo $field['id']; ?>" value="Clear Meta" />

                            <script type="text/javascript">
                                jQuery(document).ready(function ($) {
                                    $('#<?php echo esc_js($field['id']); ?>').click(function () {
                                        if (confirm("Are you sure you want to clear fields?")) {
                                            $('#<?php echo esc_js($industrial_team_option_meta['id']); ?> input[type="text"]').val('');
                                        }
                                    });
                                });
                            </script>
                        </td>
                    </tr>
                    <?php
                    break;
                case 'textarea':
                    ?><tr>
                        <th style="width:25%">
                            <label for="<?php echo $field['id']; ?>">
                                <strong><?php echo $field['name']; ?></strong>
                                <span style="display:block; color:#999; margin:5px 0 0 0; line-height: 18px;"><?php echo $field['desc']; ?></span>
                            </label>
                        </th>
                        <td>
                            <?php
                            $args = array(
                                'textarea_rows' => 5,
                                'media_buttons' => false,
                                'teeny' => true,
                                'quicktags' => false
                            );
                            wp_editor($meta ? $meta : stripslashes(htmlspecialchars(($field['std']), ENT_QUOTES)), $field['id'], $args);
                            break;
                    }
                }
                ?>
    </table>
<script>
        (function ($) {
            $(document).on("click", ".industrialcore_upload_image_button", function () {
                var adMediaFrame = wp.media({
                    title: 'Industrial - Insert a media',
                    library: {type: 'image'},
                    multiple: false,
                    button: {text: 'Insert'}
                });
                adMediaFrame.open();

                var inputText = $(this).prev();
               // var inputImg = $(this).next();
                var imageURL, attachment;
                adMediaFrame.on('select', function () {
                    attachment = adMediaFrame.state().get('selection').first().toJSON();
                    imageURL = attachment.url;
                    if (imageURL != "") {
                        inputText.val(imageURL);
                        //inputImg.attr("src", imageURL);
                    }
                });
                return false;
            });
        })(jQuery);

    </script>

    <?php
}

add_action('save_post', 'industrial_team_save_options');

// save team metadata
function industrial_team_save_options($post_id) {
    global $industrial_team_option_meta;
    $new = '';
    // verify nonce
    if (!isset($_POST['meta_box_nonce']) || !wp_verify_nonce($_POST['meta_box_nonce'], basename(__FILE__))) {
        return $post_id;
    }
    // check autosave
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return $post_id;
    }
    if (defined('DOING_AJAX') && DOING_AJAX)
        return;
    // check permissions
    if (isset($_POST['post_type']) && 'page' == $_POST['post_type']) {
        if (!current_user_can('edit_page', $post_id)) {
            return $post_id;
        }
    } elseif (!current_user_can('edit_post', $post_id)) {
        return $post_id;
    }

    foreach ($industrial_team_option_meta['fields'] as $field) {
        $old = get_post_meta($post_id, $field['id'], true);
        if (isset($_POST[$field['id']])) {
            $new = $_POST[$field['id']];
        }
        if ($new && $new != $old) {
            if ($field['id'] == 'industrialcore_team_image') {
                $new = industrialcore_get_image_id($new);
            }
            update_post_meta($post_id, $field['id'], $new);
        } elseif ('' == $new && $old) {
            delete_post_meta($post_id, $field['id'], $old);
        }
    }
}
