<?php
/**
 * Industrial - Comments
 * 
 * This is comments list template
 *
 * @package industrial
 * @since industrial 1.0.0
 */
if (!empty($_SERVER ['SCRIPT_FILENAME']) && 'comments.php' == basename($_SERVER ['SCRIPT_FILENAME']))
    die('Please do not load this page directly. Thanks!');

if (post_password_required()) {
    echo '<p class="nocomments">' . esc_html__('This post is password protected. Enter the password to view comments.', 'industrial') . '</p>';
    return;
}
function wpb_move_comment_field_to_bottom( $fields ) {
$comment_field = $fields['comment'];
unset( $fields['comment'] );
$fields['comment'] = $comment_field;
return $fields; 
}

add_filter( 'comment_form_fields', 'wpb_move_comment_field_to_bottom' );
?>

<div class="comment-box animate-effect clearfix">
    <?php if (have_comments()) : ?>
        <h3>
            <?php
            printf(// WPCS: XSS OK.
                    esc_html(_nx('One thought on &ldquo;%2$s&rdquo;', '%1$s Comments', get_comments_number(), 'comments title', 'industrial')), number_format_i18n(get_comments_number()), '<span>' . get_the_title() . '</span>'
            );
            ?>
            <i></i></h3>

        <?php if (get_comment_pages_count() > 1 && get_option('page_comments')) : // Are there comments to navigate through?  ?>
            <nav id="comment-nav-above" class="navigation comment-navigation" role="navigation">
                <h2 class="screen-reader-text"><?php esc_html_e('Comment navigation', 'industrial'); ?></h2>
                <div class="nav-links">

                    <div class="nav-previous"><?php previous_comments_link(esc_html__('Older Comments', 'industrial')); ?></div>
                    <div class="nav-next"><?php next_comments_link(esc_html__('Newer Comments', 'industrial')); ?></div>

                </div><!-- .nav-links -->
            </nav><!-- #comment-nav-above -->
        <?php endif; // Check for comment navigation.  ?>
        <ul class="clearfix ind_ul_margin">
            <?php
            wp_list_comments(array(
                'short_ping' => true,
                'avatar_size' => 90,
                'callback' => 'industrial_custom_comments',
            ));
            ?>
        </ul>
        <?php if (get_comment_pages_count() > 1 && get_option('page_comments')) : // Are there comments to navigate through? ?>
            <nav id="comment-nav-below" class="navigation comment-navigation" role="navigation">
                <h2 class="screen-reader-text"><?php esc_html_e('Comment navigation', 'industrial'); ?></h2>
                <div class="nav-links">

                    <div class="nav-previous"><?php previous_comments_link(esc_html__('Older Comments', 'industrial')); ?></div>
                    <div class="nav-next"><?php next_comments_link(esc_html__('Newer Comments', 'industrial')); ?></div>

                </div><!-- .nav-links -->
            </nav><!-- #comment-nav-below -->
        <?php endif; // Check for comment navigation.  ?>

    <?php endif; // Check for have_comments(). ?>

</div><!-- #comments -->
<div class="leavecomment-box animate-effect">
    <?php
// If comments are closed and there are comments, let's leave a little note, shall we?
    if (!comments_open() && '0' != get_comments_number() && post_type_supports(get_post_type(), 'comments')) :
        ?>
        <p class="no-comments"><?php esc_html_e('Comments are closed.', 'industrial'); ?></p>
    <?php endif; ?>

    <?php
    global $industrial_data;
    $commenter = wp_get_current_commenter();
    $aria_req = ( $req ? " aria-required='true'" : '' );

    $fields = array(
        'author' => '<div class="comment-form-input"><input type="text" id="your_name" name="author" data-validation="required" placeholder="' . esc_html__('NAME', 'industrial') . '" value="' . esc_attr($commenter['comment_author']) . '" ' . $aria_req . '  /></div>',
        'email' => '<div class="comment-form-input comment-email"><input type="text" id="your_email" value="' . esc_attr($commenter['comment_author_email']) . '" ' . $aria_req . ' placeholder="' . esc_html__('EMAIL', 'industrial') . '" data-validation="email" name="email" /></div>',
    );

    $comments_args = array(
        'fields' => $fields,
        'id_form' => 'industrial_comment_form',
        'comment_field' => '<div class="box clearfix"><textarea rows="10" id="comment" name="comment" placeholder="' . esc_html__('MESSAGE', 'industrial') . '" data-validation="required"></textarea></div>',
        'comment_notes_after' => '',
        'comment_notes_before' => '',
        'label_submit' => esc_html__('POST MESSAGE', 'industrial')
    );

    if (isset($industrial_data['industrial_cmt_tlt_en']) && $industrial_data['industrial_cmt_tlt_en']) {
        $comments_args['title_reply'] = '<span class="ind_comment_heading">' . esc_html($industrial_data['industrial_comment_tlt']) . '<i></i></span><strong>' . esc_html($industrial_data['industrial_comment_desc']) . '</strong>';
    }
    comment_form($comments_args);
    ?>
</div>
<?php 