<?php
/**
 * Industrial back compat functionality
 *
 * Prevents Industrial from running on WordPress versions prior to 4.0
 *
 * @package industrial.inc
 * @since industrial 1.0.0
 */

/**
 * Prevent switching to industrial on old versions of WordPress.
 */
function industrial_switch_theme() {
    switch_theme(WP_DEFAULT_THEME, WP_DEFAULT_THEME);
    unset($_GET['activated']);
    add_action('admin_notices', 'industrial_upgrade_notice');
}

add_action('after_switch_theme', 'industrial_switch_theme');

/**
 * Add message for unsuccessful theme switch.
 */
function industrial_upgrade_notice() {
    $message = sprintf(esc_html__('industrial requires at least WordPress version 4.0 You are running version','industrial').' %s.'.esc_html__('Please upgrade and try again.', 'industrial'), $GLOBALS['wp_version']);
    printf('<div class="error"><p>%s</p></div>', $message);
}

/**
 * Prevent the Theme Preview from being loaded on WordPress versions prior to 4.0
 */
function industrial_preview() {
    if (isset($_GET['preview'])) {
        wp_die(sprintf(esc_html__('industrial requires at least WordPress version 4.0 You are running version','industrial').' %s. '.esc_html__('Please upgrade and try again.', 'industrial'), $GLOBALS['wp_version']));
    }
}

add_action('template_redirect', 'industrial_preview');
