<?php

/**
 * Industrial - Helper Functions
 * 
 * This file has collection of industrial theme helper functions  
 *
 * @package industrial
 * @subpackage industrial.inc
 * @since industrial 1.0.0
 */
//Allow SVG upload
function industrial_mime_types($mimes) {
    $mimes['svg'] = 'image/svg+xml';
    return $mimes;
}

add_filter('upload_mimes', 'industrial_mime_types');

//Search Form Filter
function industrial_search_form($form) {
    $form = '<form id="industrial_search" class="form-inline" role="search" method="get" action="' . esc_url(home_url('/')) . '" >
			<div class="search-box">
				<input type="text" value="' . get_search_query() . '" placeholder="' . esc_html__('Search', 'industrial') . '" name="s" id="industrial_s" data-validation="required" />
				<input type="submit" value="&nbsp;" />
				<span class="form-error help-block"></span>
			</div>
          </form>';
    return $form;
}

add_filter('get_search_form', 'industrial_search_form');

//Industrial Feature Image
function industrial_set_feature_image($id, $cls = null, $w = null, $h = null) {

    if (!empty($w) && !empty($h)) {
        $src = wp_get_attachment_url(get_post_thumbnail_id($id), 'full');
        $image = industrial_resize($src, $w, $h);
        echo '<figure class="' . esc_attr($cls) . '"><a href="' . esc_url(get_the_permalink($id)) . '"><img src="' . esc_url(industrial_resize($image, $h, $w)) . '" alt="' . esc_attr(get_the_title($id)) . '" /></a></figure>';
    } else {
        $image = wp_get_attachment_url(get_post_thumbnail_id($id), 'full');
        echo '<figure class="' . esc_attr($cls) . '"><a href="' . esc_url(get_the_permalink($id)) . '"><img src="' . esc_url($image) . '" alt="' . esc_attr(get_the_title($id)) . '" /></a></figure>';
    }
    if ($id = null) {
        echo get_the_post_thumbnail($id, 'full');
    }
}

//Page Loader
function industrial_page_loader() {
	global $industrial_data;
	if (isset($industrial_data['industrial_loader_status']) && $industrial_data['industrial_loader_status']) :
    $loading = (!empty($industrial_data['industrial_loading_img']['url']))  ? $industrial_data['industrial_loading_img']['url'] : INDUSTRIAL_THEME_URL . '/assets/images/svg/grid.svg';
    ?>
    <div id="pageloader" class="row m0"><div class="loader-item"><img src="<?php echo esc_url($loading); ?>" alt="loading"></div></div>
            <?php
endif;
}

//industrial_header_layout
        add_action("wp_footer", "industrial_page_loader", 8);

//Theme Option Custom CSS 
        add_action('wp_head', 'industrial_style_option_customcss');

        function industrial_style_option_customcss() {
            global $industrial_data;
            if (!empty($industrial_data['industrial_customcss'])):
                ?><style><?php
                print($industrial_data['industrial_customcss']);
                ?></style><?php
    endif;
}

//Get page id by page template

function industrial_page_template_id($page_template) {
    $args = array(
        'post_type' => 'page',
        'fields' => 'ids',
        'nopaging' => true,
        'meta_key' => '_wp_page_template',
        'meta_value' => $page_template
    );
    $pages = get_posts($args);
    $page_id = false;
    if (is_array($pages)):
        foreach ($pages as $page):
            $page_id = $page;
            break;
        endforeach;
    endif;
    return $page_id;
}


function industrial_set_feature_image_blog($id, $cls = null, $w = null, $h = null) {
	
    if (!empty($w) && !empty($h)) {
        $src = wp_get_attachment_url(get_post_thumbnail_id($id), 'full');
        $image = industrial_resize($src, $w, $h);
        echo '<figure class="' . esc_attr($cls) . '"><a href="' . esc_url(get_the_permalink($id)) . '"><img src="' . esc_url($image) . '" alt="' . esc_attr(get_the_title($id)) . '" /></a></figure>';
    } else {
        $image = wp_get_attachment_url(get_post_thumbnail_id($id), 'full');
        echo '<figure class="' . esc_attr($cls) . '"><a href="' . esc_url(get_the_permalink($id)) . '"><img src="' . esc_url($image) . '" alt="' . esc_attr(get_the_title($id)) . '" /></a></figure>';
    }
    if ($id = null) {
        echo get_the_post_thumbnail($id, 'full');
    }
}

/*
 * truncate content
 */
function industrial_truncate_content($string, $chars = 50) {

	// ----- remove HTML TAGs -----
	$string = preg_replace('/<[^>]*>/', ' ', $string);
	$string = preg_replace('/\[.*?\]/', ' ', $string); //-- remove shortcode
	// ----- remove control characters -----
	$string = str_replace("\r", '', $string);    // --- replace with empty space
	$string = str_replace("\n", ' ', $string);   // --- replace with space
	$string = str_replace("\t", ' ', $string);   // --- replace with space
	// ----- remove multiple spaces -----
	$string = trim(preg_replace('/ {2,}/', ' ', $string));

	$len = strlen($string);

	if ($len > $chars) {
		$string = substr($string, 0, $chars);
		//$string = substr($string,0,strrpos($string,' '));
		//$string = $string."...";
	}

	return $string;
}
/*
 * check is unittest data or not 
 */
add_action("init", "industrial_unit_test_data");

function industrial_unit_test_data(){
	$unitdata=get_option("industrial_unit_data");
	$ind_query=new WP_Query(array("s"=> "Unit Test"));
	if($ind_query->found_posts > 1 && $unitdata != "unit"){
		update_option("industrial_unit_data", "unit");
	}
	wp_reset_postdata();
}

function industrial_is_unitdata(){
	$unitdata=get_option("industrial_unit_data");
	if($unitdata == "unit"){
		return true;
	}
	else{
		return false;
	}
}



/**
 * Coming Soon - Template Redirection
 * @global type $industrial_data
 */
function industrial_comingsoon_redirect()
{
     global $industrial_data;
    $coming_soon_option=$industrial_data['industrial_comming_soon'];
    if($coming_soon_option && ! is_user_logged_in()){
	industrial_inclusion('content/industrial-coming-soon.php');
        die();
    }
}
add_action( 'template_redirect', 'industrial_comingsoon_redirect' );

/**
 * Coming Soon - admin notices
 * @global type $industrial_data
 */
function industrial_coming_soon_notice(){
    
     global $industrial_data;
    $coming_soon_option=$industrial_data['industrial_comming_soon'];
    if($coming_soon_option ){
            $message = esc_html__('Industrial Theme  activated in coming soon mode.', 'industrial');
         printf('<div class="error"><p><strong>%s</strong></p></div>', $message);

    }
}

add_action('admin_notices', 'industrial_coming_soon_notice');
