<?php

/**
 * Industrial - Page Layout settings
 * 
 * Action of theme layout & header layout 
 *
 * @package     industrial
 * @subpackage industrial.inc 
 * @since   industrial  1.0.0
 */
class IndustrialPageLayout {

    public function __construct() {
        $this->action();
    }

    function action() {
        add_action("industrial_header_layout", array(&$this, "industrial_header"));
        add_action("redux/options/industrial_data/settings/change", array(&$this, "industrial_set_home_page"));
        
        add_action("industrial_theme_layout_class", array(&$this, "theme_class"));
        add_action("industrial_banner_parallax", array(&$this, "banner_parallax"));
    }

    function banner_parallax($args) {
        if (empty($args["img"])):
            global $industrial_data;
            $image = (!empty($industrial_data['industrial_page_header_bg_img']['url'])) ? $industrial_data['industrial_page_header_bg_img']['url'] : INDUSTRIAL_THEME_URL . '/assets/images/banner-bg.jpg';
        else:
            $image = $args["img"];
        endif;
        ?>
        <div id="slider" class="banner-container parallax" style="background: url('<?php echo esc_url($image); ?>') no-repeat;">
            <div class="container">
                <div class="row">
                    <div class="col-xs-12">
                        <h3><?php echo esc_html($args['title']); ?></h3>
                    </div>
                </div>
            </div>
        </div>
        <?php
    }

    function theme_class() {
        global $industrial_data;
        $class = ($industrial_data['industrial_theme_layout']) ? $industrial_data['industrial_theme_layout'] : "full-width";
        printf("class='" . $class . "'");
    }

    function industrial_header() {
        global $industrial_data;
        $layoutOption = (!empty($industrial_data['industrial_theme'])) ? $industrial_data['industrial_theme'] : 'theme1';
        $slug = "content/header/one";

        switch ($layoutOption) {
            case "theme2":
                $slug = "content/header/two";
                break;
            case "theme3":
                $slug = "content/header/three";
                break;
            case "theme4":
                $slug = "content/header/four";
                break;
            case "theme5":
                $slug = "content/header/five";
                break;
            case "theme6":
                $slug = "content/header/six";
                break;
            default:
                $slug = "content/header/one";
                break;
        }
        get_template_part($slug);
        $this->home_slider();
    }

    function home_slider() {

        global $post;
        if (is_object($post)):
            $slider = get_post_meta($post->ID, 'industrialcore_slider_slider', true);
            if (!empty($slider) && has_shortcode($slider, 'rev_slider')) :
                ?>
                <section id="slider">
                    <?php echo do_shortcode($slider); ?>
                </section>
                <?php
            endif;

        endif;
    }

    
    /**
     * Home page layout
     */
    function industrial_set_home_page() {
        global $industrial_data;
        
        
        $theme = $industrial_data["industrial_theme"];

        $home1 = $industrial_data["industrial_home_1"];
        $home2 = $industrial_data["industrial_home_2"];
        $home3 = $industrial_data["industrial_home_3"];
        $home4 = $industrial_data["industrial_home_4"];
        $home5 = $industrial_data["industrial_home_5"];
        $home6 = $industrial_data["industrial_home_6"];

        $show_on_front = get_option("show_on_front");
        $page_on_front = get_option("page_on_front");

        $home = "";
        switch ($theme):
            case "theme1": $home = $home1;
                break;
            case "theme2": $home = $home2;
                break;
            case "theme3": $home = $home3;
                break;
            case "theme4": $home = $home4;
                break;
            case "theme5": $home = $home5;
                break;
            case "theme6": $home = $home6;
                break;
        endswitch;
        if ($page_on_front != $home):
            update_option("show_on_front", "page");
            update_option('page_on_front', $home);
        endif;
    }
    
}

new IndustrialPageLayout();



/**
 * Home page comming soon mode
 */

