<?php
/*
 * Industrial - breadcrumb
 *
 * @package     industrial
 * @subpackage industrial.inc
 * @since industrial 1.0.0
 * */

//industrial_banner_parallax

add_action("industrial_banner_parallax", "industrial_breadcrum_ui", 11);

function industrial_breadcrum_ui() {
    global $post;
    ?>
    <div class="clearfix">
        <div class="container">
            <div class="row">
                <div class="col-xs-12">
                    <div class="breadcrumbs-box"><?php industrial_breadcrumb(); ?>
                    </div>
                </div>
            </div>
        </div>
    </div> 
    <?php
}

function industrial_breadcrumb() {

    $delimiter = ''; // delimiter between crumbs
    $home = esc_html__('Home', 'industrial'); // text for the 'Home' link
    $showCurrent = 1; // 1 - show current post/page title in breadcrumbs, 0 - don't show
    $before = '<li class="active">'; // tag before the current crumb
    $after = '</li>'; // tag after the current crumb

    global $post;
    $homeLink = home_url('/');

    echo '<ul class="clearfix breadcrumb"><li><a href="' . esc_url($homeLink) . '">' . $home . '</a></li> ' . wp_kses_post($delimiter) . ' ';

    if (is_category()) {

        $thisCat = get_category(get_query_var('cat'), false);
        if ($thisCat->parent != 0)
            echo get_category_parents($thisCat->parent, TRUE, ' ' . $delimiter . ' ');
        echo wp_kses_post($before) . single_cat_title('', false) . wp_kses_post($after);
    } elseif (is_search()) {
        echo wp_kses_post($before) . esc_html__('Search results for "', "industrial") . get_search_query() . '"' . wp_kses_post($after);
    } elseif (is_day()) {
        echo '<li><a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a></li> ' . wp_kses_post($delimiter) . ' ';
        echo '<li><a href="' . get_month_link(get_the_time('Y'), get_the_time('m')) . '">' . get_the_time('F') . '</a></li> ' . wp_kses_post($delimiter) . ' ';
        echo wp_kses_post($before) . get_the_time('d') . wp_kses_post($after);
    } elseif (is_month()) {
        echo '<li><a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a></li> ' . wp_kses_post($delimiter) . ' ';
        echo wp_kses_post($before) . get_the_time('F') . wp_kses_post($after);
    } elseif (is_year()) {
        echo wp_kses_post($before) . get_the_time('Y') . wp_kses_post($after);
    } elseif (is_single() && !is_attachment()) {
        if (get_post_type() != 'post') {
            $post_type = get_post_type_object(get_post_type());
            $slug = $post_type->rewrite;
            echo '<li><a href="' . $homeLink . '/' . $slug['slug'] . '">' . $post_type->labels->singular_name . '</a></li>';
            if ($showCurrent == 1)
                echo ' ' . wp_kses_post($delimiter) . ' ' . wp_kses_post($before) . get_the_title() . wp_kses_post($before);
        } else {
            $cat = get_the_category();
            $cat = $cat[0];
            $cats = get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
            if ($showCurrent == 0)
                $cats = preg_replace("#^(.+)\s".$delimiter."\s$#", "$1", $cats);
            echo '<li>' . $cats . '</li>';
            if ($showCurrent == 1)
                echo wp_kses_post($before) . get_the_title() . wp_kses_post($after);
        }
    } elseif (!is_single() && !is_page() && get_post_type() != 'post' && !is_404() && !is_author()) {
        $post_type = get_post_type_object(get_post_type());
        echo wp_kses_post($before) . $post_type->labels->singular_name . wp_kses_post($after); //-----post type/taxonomy
    } elseif (is_attachment()) {
        $parent = get_post($post->post_parent);
        $cat = get_the_category($parent->ID);
	if(isset($cat[0])) {
        $cat = $cat[0];
	}
        echo is_wp_error($cat_parents = get_category_parents($cat, TRUE, '' . wp_kses_post($delimiter) . '')) ? '' : $cat_parents;
        echo '<li><a href="' . get_permalink($parent) . '">' . $parent->post_title . '</a></li>';
        if ($showCurrent == 1)
            echo '' . wp_kses_post($delimiter) . ' ' . wp_kses_post($before) . get_the_title() . wp_kses_post($after);
    } elseif (is_page() && !$post->post_parent) {
        if ($showCurrent == 1)
            echo wp_kses_post($before) . get_the_title() . wp_kses_post($after);
    } elseif (is_page() && $post->post_parent) {
        $parent_id = $post->post_parent;
        $breadcrumbs = array();
        while ($parent_id) {
            $page = get_page($parent_id);
            $breadcrumbs[] = '<li><a href="' . get_permalink($page->ID) . '">' . get_the_title($page->ID) . '</a></li>';
            $parent_id = $page->post_parent;
        }
        $breadcrumbs = array_reverse($breadcrumbs);
        for ($i = 0; $i < count($breadcrumbs); $i++) {
            echo wp_kses_post($breadcrumbs[$i]);
            if ($i != count($breadcrumbs) - 1)
                echo ' ' . wp_kses_post($delimiter) . ' ';
        }
        if ($showCurrent == 1)
            echo ' ' . wp_kses_post($delimiter) . ' ' . wp_kses_post($before) . get_the_title() . wp_kses_post($after);
    } elseif (is_tag()) {
        echo wp_kses_post($before) . esc_html__('Posts tagged "', "industrial") . single_tag_title('', false) . '"' . wp_kses_post($after);
    } elseif (is_author()) {
        global $author;
        $userdata = get_userdata($author);
        echo wp_kses_post($before) . esc_html__('Articles posted by ', "industrial") . $userdata->display_name . wp_kses_post($after);
    } elseif (is_404()) {
        echo wp_kses_post($before) . esc_html__('Error 404', "industrial") . wp_kses_post($after);
    }

//    if ( get_query_var('paged') ) {
//      if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ' (';
//      echo esc_html__('Page', 'bblog') . ' ' . get_query_var('paged');
//      if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ')';
//    }

    echo '</ul>';
}
