<?php
/**
 * Industrial theme setup functionality
 *
 * @package  industrial
 * @subpackage industrial.inc
 * @since industrial 1.0.0
 */
if (version_compare($GLOBALS['wp_version'], '3.9', '<')) {
    industrial_inclusion('inc/back-compat.php');
}
/**
 * industrial_setup
 */
if (!function_exists('industrial_setup')) :

    function industrial_setup() {
        load_theme_textdomain('industrial', get_template_directory() . '/languages');
        add_theme_support('automatic-feed-links');
        add_theme_support('title-tag');
        add_theme_support('post-thumbnails');
        // This theme uses wp_nav_menu() in one location.
        register_nav_menus(array(
            'primary' => esc_html__('Industrial Menu', 'industrial'),
            'footer_primary' => esc_html__('Industrial Footer Menu', 'industrial'),
        ));
        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support('html5', array('search-form', 'comment-form', 'comment-list', 'gallery', 'caption',));
        // Enable support for Post Formats.
        add_theme_support('post-formats', array('aside', 'image', 'video', 'quote', 'link',));

        add_image_size("industrial_blog", 957, 400, true);
        add_image_size("industrial_blog_small", 432, 378, true);
        update_option('revslider-valid', 'true');
    }

endif;
add_action('after_setup_theme', 'industrial_setup');

/**
 * @global int $content_width
 */
function industrial_content_width() {
    $GLOBALS['content_width'] = $content_width = 474;
}

add_action('after_setup_theme', 'industrial_content_width', 0);

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function industrial_body_classes($classes) {
    global $industrial_data;
    $layoutOption = ($industrial_data['industrial_theme']) ? $industrial_data['industrial_theme'] : "theme1";
    $classes[] = "industrial-" . $layoutOption;
    // Adds a class of group-blog to blogs with more than 1 published author.
    if (is_multi_author()) {
        $classes[] = 'group-blog';
    }
    return $classes;
}

add_filter('body_class', 'industrial_body_classes');

if (version_compare($GLOBALS['wp_version'], '4.1', '<')) :

    /**
     * Filters wp_title to print a neat <title> tag based on what is being viewed.
     *
     * @param string $title Default title text for current view.
     * @param string $sep Optional separator.
     * @return string The filtered title.
     */
    function industrial_wp_title($title, $sep) {
        if (is_feed()) {
            return $title;
        }

        global $page, $paged;

        // Add the blog name.
        $title .= get_bloginfo('name', 'display');

        // Add the blog description for the home/front page.
        $site_description = get_bloginfo('description', 'display');
        if ($site_description && ( is_home() || is_front_page() )) {
            $title .= " $sep $site_description";
        }

        // Add a page number if necessary.
        if (( $paged >= 2 || $page >= 2 ) && !is_404()) {
            $title .= " $sep " . sprintf(esc_html__('Page %s', 'industrial'), max($paged, $page));
        }

        return $title;
    }

    add_filter('wp_title', 'industrial_wp_title', 10, 2);

    /**
     * Title shim for sites older than WordPress 4.1.
     *
     * @link https://make.wordpress.org/core/2014/10/29/title-tags-in-4-1/
     * @todo Remove this function when WordPress 4.3 is released.
     */
    function industrial_render_title() {
        ?>
        <title><?php wp_title('|', true, 'right'); ?></title>
        <?php
    }

    add_action('wp_head', 'industrial_render_title');
endif;

/**
 * Avoid Theme Support feature
 * We are using Option
 */
add_theme_support('custom-header');
remove_theme_support('custom-header');

add_theme_support('custom-background');
remove_theme_support('custom-background');

add_editor_style();
remove_editor_styles();
add_filter('deprecated_constructor_trigger_error', '__return_false');

/**
 * Industrial - Nav Menu Fallback
 * if no menu assign then provide login user edit menu
 * 
 * @description wp_nav_menu
 * @since industrial 1.0.0
 */
if (!function_exists('industrial_menu_editor')) {

    function industrial_menu_editor($args) {
        if (!current_user_can('manage_options')) {
            return;
        }

        // see wp-includes/nav-menu-template.php for available arguments
        extract($args);

        $link = $link_before
                . '<a href="' . admin_url('nav-menus.php') . '">' . $before . 'Add a menu' . $after . '</a>'
                . $link_after;

        // We have a list
        if (FALSE !== stripos($items_wrap, '<ul') or FALSE !== stripos($items_wrap, '<ol')
        ) {
            $link = "<li>$link</li>";
        }

        $output = sprintf($items_wrap, $menu_id, $menu_class, $link);
        if (!empty($container)) {
            $output = "<$container class='$container_class' id='$container_id'>$output</$container>";
        }

        if ($echo) {
            print($output);
        }

        return $output;
    }

}

add_action("admin_init", "industrial_theme_activate");

function industrial_theme_activate() {
    if (is_admin() && isset($_GET['activated'])) {
       wp_redirect(admin_url("themes.php?page=theemon-importer"));
       die();
    }
}
